@@ -12,7 +12,8 @@ from grid2op.Exceptions.Grid2OpException import Grid2OpException
 # ambiguous action
 class AmbiguousAction(Grid2OpException):
     """
-    This exception indicate that the :class:`grid2op.BaseAction` is ambiguous. It could be understood differently according
+    This exception indicate that the :class:`grid2op.BaseAction` is ambiguous.
+    It could be understood differently according
     to the backend used.
 
     Such a kind of action are forbidden in this package. These kind of exception are mainly thrown by the
@@ -29,31 +30,40 @@ class AmbiguousAction(Grid2OpException):
 
 class InvalidLineStatus(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction` is
-    ambiguous due to powerlines manipulation.
+    This is a more precise exception than :class:`AmbiguousAction` indicating that the
+     :class:`grid2op.BaseAction.BaseAction` is ambiguous due to powerlines manipulation.
+    """
+    pass
+
+
+class InvalidStorage(AmbiguousAction):
+    """
+    This is a more precise exception than :class:`AmbiguousAction` indicating that the
+     :class:`grid2op.BaseAction.BaseAction` is ambiguous due to storage unit manipulation.
     """
     pass
 
 
 class UnrecognizedAction(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction` is
-    ambiguous due to the bad formatting of the action.
+    This is a more precise exception than :class:`AmbiguousAction` indicating that the
+    :class:`grid2op.BaseAction.BaseAction` is  ambiguous due to the bad formatting of the action.
     """
     pass
 
 
 class InvalidNumberOfLoads(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction`
-    is ambiguous because an incorrect number of loads tries to be modified.
+    This is a more precise exception than :class:`AmbiguousAction` indicating that
+    the :class:`grid2op.BaseAction.BaseAction` is ambiguous because an incorrect number of loads tries to be modified.
     """
     pass
 
 
 class InvalidNumberOfGenerators(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction`
+    This is a more precise exception than :class:`AmbiguousAction` indicating that
+    the :class:`grid2op.BaseAction.BaseAction`
     is ambiguous because an incorrect number of generator tries to be modified.
     """
     pass
@@ -61,7 +71,8 @@ class InvalidNumberOfGenerators(AmbiguousAction):
 
 class InvalidNumberOfLines(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction`
+    This is a more precise exception than :class:`AmbiguousAction` indicating that
+    the :class:`grid2op.BaseAction.BaseAction`
     is ambiguous because an incorrect number of lines tries to be modified.
     """
     pass
@@ -69,7 +80,8 @@ class InvalidNumberOfLines(AmbiguousAction):
 
 class InvalidNumberOfObjectEnds(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction`
+    This is a more precise exception than :class:`AmbiguousAction` indicating that
+    the :class:`grid2op.BaseAction.BaseAction`
     is ambiguous because an incorrect number of object at a substation try to be modified.
     """
     pass
@@ -77,7 +89,8 @@ class InvalidNumberOfObjectEnds(AmbiguousAction):
 
 class InvalidBusStatus(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction`
+    This is a more precise exception than :class:`AmbiguousAction` indicating that
+    the :class:`grid2op.BaseAction.BaseAction`
     try to both "set" and "switch" some bus to which an object is connected.
     """
     pass
@@ -85,12 +98,22 @@ class InvalidBusStatus(AmbiguousAction):
 
 class InvalidRedispatching(AmbiguousAction):
     """
-    This is a more precise exception than :class:`AmbiguousAction` indicating that the :class:`grid2op.BaseAction.BaseAction`
+    This is a more precise exception than :class:`AmbiguousAction` indicating that
+    the :class:`grid2op.BaseAction.BaseAction`
     try to apply an invalid redispatching strategy.
     """
     pass
 
 
+class InvalidCurtailment(AmbiguousAction):
+    """
+    This is a more precise exception than :class:`AmbiguousAction` indicating that
+    the :class:`grid2op.BaseAction.BaseAction`
+    try to apply an invalid curtailment strategy.
+    """
+    pass
+
+
 class GeneratorTurnedOnTooSoon(InvalidRedispatching):
     """
     This is a more precise exception than :class:`AmbiguousAction` indicating that a generator has been turned on
@@ -113,3 +136,12 @@ class NotEnoughGenerators(InvalidRedispatching):
     generators to meet the demand.
     """
     pass
+
+
+class NonFiniteElement(InvalidRedispatching):
+    """
+    This is a more precise exception than :class:`AmbiguousAction` indicating that an action / observation
+    non initialized (full of Nan)
+    has been loaded by the "from_vect" method.
+    """
+    pass
