@@ -30,6 +30,7 @@ PATH_CHRONICS_Make2 = os.path.abspath(os.path.join(grid2op_dir, "data"))
 PATH_DATA_TEST_PP = os.path.abspath(os.path.join(PATH_DATA_TEST, "test_PandaPower"))
 EXAMPLE_CHRONICSPATH = os.path.abspath(os.path.join(data_dir, "5bus_example", "chronics"))
 EXAMPLE_CASEFILE = os.path.abspath(os.path.join(data_dir, "5bus_example", "5bus_example.json"))
+PATH_DATA_MULTIMIX = os.path.abspath(os.path.join(data_dir, "multimix"))
 
 
 class HelperTests(unittest.TestCase):
@@ -39,4 +40,6 @@ class HelperTests(unittest.TestCase):
         self.tol_one = dt_float(1e-5)
 
     def compare_vect(self, pred, true):
-        return dt_float(np.max(np.abs(pred - true))) <= self.tolvect
+        res = dt_float(np.max(np.abs(pred - true))) <= self.tolvect
+        res = res and dt_float(np.mean(np.abs(pred - true))) <= self.tolvect
+        return res
