@@ -21,9 +21,9 @@ from grid2op.Chronics import ChronicsHandler, GridStateFromFile, ChangeNothing
 from grid2op.Reward import L2RPNReward
 from grid2op.MakeEnv import make
 from grid2op.Rules import RulesChecker, DefaultRules
-from grid2op.Action import *
 from grid2op.dtypes import dt_float
 
+
 DEBUG = False
 PROFILE_CODE = False
 if PROFILE_CODE:
@@ -219,7 +219,7 @@ class TestLoadingBackendPandaPower(unittest.TestCase):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
             self.env = Environment(init_grid_path=os.path.join(self.path_matpower, self.case_file),
-                                   backend=self.backend,
+                                   backend=self.get_backend(),
                                    chronics_handler=self.chronics_handler,
                                    parameters=self.env_params,
                                    rewardClass=L2RPNReward,
