@@ -1,4 +1,5 @@
-__all__ = ["EpisodeStatistics", "ScoreL2RPN2020"]
+__all__ = ["EpisodeStatistics", "ScoreL2RPN2020", "ScoreICAPS2021"]
 
 from grid2op.utils.underlying_statistics import EpisodeStatistics
 from grid2op.utils.l2rpn_2020_scores import ScoreL2RPN2020
+from grid2op.utils.icaps_2021_scores import ScoreICAPS2021
